==> haskell-butcher-1.3.3.2-387-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-butcher.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 butcher
version:              1.3.3.2
visibility:           public
id:                   butcher-1.3.3.2-Er6GvbZLb1JJaANZLhPprM
key:                  butcher-1.3.3.2-Er6GvbZLb1JJaANZLhPprM
license:              BSD-3-Clause
copyright:            Copyright (C) 2016-2020 Lennart Spitzner
maintainer:           Lennart Spitzner <hexagoxel@hexagoxel.de>
author:               Lennart Spitzner
stability:            experimental
homepage:             https://github.com/lspitzner/butcher/
synopsis:
    Chops a command or program invocation into digestable pieces.

description:
    See the <https://github.com/lspitzner/butcher/blob/master/README.md README> (it is properly formatted on github).

category:             UI
abi:                  ce4ff4a7933adbdebda1947398f1f2dd
exposed:              True
exposed-modules:
    UI.Butcher.Monadic UI.Butcher.Monadic.BuiltinCommands
    UI.Butcher.Monadic.Command UI.Butcher.Monadic.Flag
    UI.Butcher.Monadic.IO UI.Butcher.Monadic.Interactive
    UI.Butcher.Monadic.Param UI.Butcher.Monadic.Pretty
    UI.Butcher.Monadic.Types

hidden-modules:
    UI.Butcher.Monadic.Internal.Types UI.Butcher.Monadic.Internal.Core

import-dirs:          /usr/lib/ghc-9.4.8/site-local/butcher-1.3.3.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/butcher-1.3.3.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/butcher-1.3.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-butcher
hs-libraries:         HSbutcher-1.3.3.2-Er6GvbZLb1JJaANZLhPprM
depends:
    base-4.17.2.1 bifunctors-5.6-9UAdy2Rz8TK2BlMm8XQUvc
    containers-0.6.7 deque-0.4.4.1-9otg74PSUO66yqJ3vcZ1rs
    extra-1.7.16-Dogq4JQiVI0JTl9E7yM5k0 free-5.2-6XzfBaBNYAXDXFzJJLivZy
    microlens-0.4.13.1-BCmTOusOWAwKF1xfvNhRYd
    microlens-th-0.4.3.17-GNytIaHmI1f32SxxcUFLLO mtl-2.2.2
    multistate-0.8.0.4-KzWibv3g6DH9jpngQ7rWCQ pretty-1.1.3.6
    transformers-0.5.6.2 unsafe-0.0-GQ6Zydb4lCS7B1Ck4GrK4S
    void-0.7.3-H00KtmFLEBuFgBidznP5Pq

haddock-interfaces:   /usr/share/doc/haskell-butcher/html/butcher.haddock
haddock-html:         /usr/share/doc/haskell-butcher/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-butcher-1.3.3.2-388-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-butcher.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 butcher
version:              1.3.3.2
visibility:           public
id:                   butcher-1.3.3.2-GpJJJ9rmrdYCZzHDpO5VCk
key:                  butcher-1.3.3.2-GpJJJ9rmrdYCZzHDpO5VCk
license:              BSD-3-Clause
copyright:            Copyright (C) 2016-2020 Lennart Spitzner
maintainer:           Lennart Spitzner <hexagoxel@hexagoxel.de>
author:               Lennart Spitzner
stability:            experimental
homepage:             https://github.com/lspitzner/butcher/
synopsis:
    Chops a command or program invocation into digestable pieces.

description:
    See the <https://github.com/lspitzner/butcher/blob/master/README.md README> (it is properly formatted on github).

category:             UI
abi:                  768dc8493303e5b9abd5257f10703ead
exposed:              True
exposed-modules:
    UI.Butcher.Monadic UI.Butcher.Monadic.BuiltinCommands
    UI.Butcher.Monadic.Command UI.Butcher.Monadic.Flag
    UI.Butcher.Monadic.IO UI.Butcher.Monadic.Interactive
    UI.Butcher.Monadic.Param UI.Butcher.Monadic.Pretty
    UI.Butcher.Monadic.Types

hidden-modules:
    UI.Butcher.Monadic.Internal.Types UI.Butcher.Monadic.Internal.Core

import-dirs:          /usr/lib/ghc-9.4.8/site-local/butcher-1.3.3.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/butcher-1.3.3.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/butcher-1.3.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-butcher
hs-libraries:         HSbutcher-1.3.3.2-GpJJJ9rmrdYCZzHDpO5VCk
depends:
    base-4.17.2.1 bifunctors-5.6-5ugersqAbphDZZaliZFqKD
    containers-0.6.7 deque-0.4.4.1-6YJm2px3dYN9BqZx3xTqxX
    extra-1.7.16-9yFW5HMy3QJKMvZBMWGOPz free-5.2-CbYHK2gYcEs2aFQR5gxgcO
    microlens-0.4.13.1-BCmTOusOWAwKF1xfvNhRYd
    microlens-th-0.4.3.17-GNytIaHmI1f32SxxcUFLLO mtl-2.2.2
    multistate-0.8.0.4-KzWibv3g6DH9jpngQ7rWCQ pretty-1.1.3.6
    transformers-0.5.6.2 unsafe-0.0-GQ6Zydb4lCS7B1Ck4GrK4S
    void-0.7.3-H00KtmFLEBuFgBidznP5Pq

haddock-interfaces:   /usr/share/doc/haskell-butcher/html/butcher.haddock
haddock-html:         /usr/share/doc/haskell-butcher/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
